/*
 *	var.c
 *
 *	global variables
 */

#define K_EXTERN
#include "mhpopd.h"
#include "kctype.h"

char *myname = NULL;
char *mydomain = NULL;
CONST char nullstr[] = "";
CONST char curstr[] = "cur";
CONST char draftstr[] = "draft";
CONST char curfolderstr[] = "Current-Folder";
CONST char pathsocket[] = "(socket)";
CONST char pathpty[] = "(pty)";
CONST char pathstdin[] = "(stdin)";
CONST char pathstdout[] = "(stdout)";
CONST char pathstderr[] = "(stderr)";
char *origtty = NULL;
char *origws = NULL;
char **pwd_envp = NULL;
int sig_ignore = 0;
char log_buf[MAXLINEBUF + 1] = "";
char *auth_passwd = NULL;
int mh_protocol = MHP_POP3;
int isinetd = 0;
int ischild = 0;
int isdaemon = 0;

char *spooldir = NULL;
char *inboxdir = NULL;
char *draftdir = NULL;
char *mhbindir = NULL;
char *incproc = NULL;
char *rmmproc = NULL;
char *sendproc = NULL;
char *context = NULL;
int msgprotect = 0;
int folderprotect = 0;
char *sequence = NULL;
char *passwdfile = NULL;
char *incprompt = NULL;
char *pickfile = NULL;
char *envpath = NULL;
int inctimeout = 0;
int rmmtimeout = 0;
int sendtimeout = 0;
int picktimeout = 0;
int daemonize = 0;
int interactive = 0;
char *serverrc = NULL;
int portno = 0;
char *piddir = NULL;
char *homepiddir = NULL;
char *logdir = NULL;
int maxlogsize = 0;
int nosyslog = 0;
char *allowfile = NULL;
char *denyfile = NULL;
char *hostname = NULL;
char *mhprofile = NULL;
char *mhpopdrc = NULL;
int sockettimeout = 0;
char *mypasswd = NULL;
char *folders = NULL;
int debuglevel = 0;
